==> zabbix-agent2-plugin-postgresql_6.0.44.orig.tar.gz: zabbix-agent2-plugin-postgresql-6.0.44/plugin/handler_autovacuum.go <==
/*
** Zabbix
** Copyright (C) 2001-2026 Zabbix SIA
**
** Licensed under the Apache License, Version 2.0 (the "License");
** you may not use this file except in compliance with the License.
** You may obtain a copy of the License at
**
**     http://www.apache.org/licenses/LICENSE-2.0
**
** Unless required by applicable law or agreed to in writing, software
** distributed under the License is distributed on an "AS IS" BASIS,
** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
** See the License for the specific language governing permissions and
** limitations under the License.
**/

package plugin

import (
	"context"
	"errors"

	"github.com/jackc/pgx/v4"
	"golang.zabbix.com/sdk/zbxerr"
)

// autovacuumHandler returns count of autovacuum workers if all is OK or nil otherwise.
func autovacuumHandler(ctx context.Context, conn PostgresClient,
	_ string, _ map[string]string, _ ...string) (interface{}, error) {
	var countAutovacuumWorkers int64

	query := `SELECT count(*)
				FROM pg_catalog.pg_stat_activity
				WHERE backend_type = 'autovacuum worker'
				 AND state <> 'idle'
				 AND pid <> pg_catalog.pg_backend_pid()`

	row, err := conn.QueryRow(ctx, query)
	if err != nil {
		return nil, zbxerr.ErrorCannotFetchData.Wrap(err)
	}

	err = row.Scan(&countAutovacuumWorkers)
	if err != nil {
		if errors.Is(err, pgx.ErrNoRows) {
			return nil, zbxerr.ErrorEmptyResult.Wrap(err)
		}

		return nil, zbxerr.ErrorCannotFetchData.Wrap(err)
	}

	return countAutovacuumWorkers, nil
}

==> zabbix-agent2-plugin-postgresql_6.4.11~rc1.orig.tar.gz: zabbix-agent2-plugin-postgresql-6.4.11rc1/plugin/handler_autovacuum.go <==
/*
** Zabbix
** Copyright 2001-2024 Zabbix SIA
**
** Licensed under the Apache License, Version 2.0 (the "License");
** you may not use this file except in compliance with the License.
** You may obtain a copy of the License at
**
**     http://www.apache.org/licenses/LICENSE-2.0
**
** Unless required by applicable law or agreed to in writing, software
** distributed under the License is distributed on an "AS IS" BASIS,
** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
** See the License for the specific language governing permissions and
** limitations under the License.
**/

package plugin

import (
	"context"
	"errors"

	"git.zabbix.com/ap/plugin-support/zbxerr"
	"github.com/jackc/pgx/v4"
)

// autovacuumHandler returns count of autovacuum workers if all is OK or nil otherwise.
func autovacuumHandler(ctx context.Context, conn PostgresClient,
	_ string, _ map[string]string, _ ...string) (interface{}, error) {
	var countAutovacuumWorkers int64

	query := `SELECT count(*)
				FROM pg_catalog.pg_stat_activity
			   WHERE query like '%%autovacuum%%'
				 AND state <> 'idle'
				 AND pid <> pg_catalog.pg_backend_pid()`

	row, err := conn.QueryRow(ctx, query)
	if err != nil {
		return nil, zbxerr.ErrorCannotFetchData.Wrap(err)
	}

	err = row.Scan(&countAutovacuumWorkers)
	if err != nil {
		if errors.Is(err, pgx.ErrNoRows) {
			return nil, zbxerr.ErrorEmptyResult.Wrap(err)
		}

		return nil, zbxerr.ErrorCannotFetchData.Wrap(err)
	}

	return countAutovacuumWorkers, nil
}
